import os

BASE_PATH = os.path.dirname(__file__)

QUNIT_TEST_DIRECTORY = os.path.join(BASE_PATH, 'qunit_tests')

DEBUG = True
TEMPLATE_DEBUG = DEBUG

ROOT_URLCONF = 'example.urls'

INSTALLED_APPS = (
    'django_qunit',
)



from django.core.exceptions import ImproperlyConfigured
from django.conf import settings

try:
    settings.QUNIT_TEST_DIRECTORY
except AttributeError:
    raise ImproperlyConfigured('Missing required setting QUNIT_TEST_DIRECTORY.')



from django.shortcuts import render_to_response
from django.conf import settings
from django.utils import simplejson

import os

def run_tests(request, path):
    full_path = os.path.join(settings.QUNIT_TEST_DIRECTORY, path)
    full_path, directories, files = os.walk(full_path).next()

    suite = {}

    # set suite name
    pieces = path.split('/')
    if len(pieces) < 2:
        suite['name'] = 'main'
    else:
        suite['name'] = ''.join(pieces[-2])

    # defaults
    suite['extra_urls'] = []
    suite['extra_media_urls'] = []

    # load suite.json if present
    if 'suite.json' in files:
        file = open(os.path.join(full_path, 'suite.json'), 'r')
        json = file.read()
        suite.update(simplejson.loads(json))

    previous_directory = parent_directory(path)

    return render_to_response('qunit/index.html', {
        'files': [path + file for file in files if file.endswith('js')],
        'previous_directory': previous_directory,
        'in_subdirectory': True and (previous_directory is not None) or False,
        'subsuites': directories,
        'suite': suite,
    })

def parent_directory(path):
    """
    Get parent directory. If root, return None
    "" => None
    "foo/" => "/"
    "foo/bar/" => "foo/"
    """
    if path == '':
        return None
    prefix = '/'.join(path.split('/')[:-2])
    if prefix != '':
        prefix += '/'
    return prefix



from django.conf.urls.defaults import *
from django.conf import settings
import os

media_root = os.path.join(os.path.dirname(__file__), 'media')

urlpatterns = patterns('',
    url(r'^tests/(?P<path>.*)$', 'django.views.static.serve', {
        'document_root': settings.QUNIT_TEST_DIRECTORY,
    }, name='qunit_test'),
    url(r'^qunit/qunit.js', 'django.views.static.serve', {
        'document_root': media_root, 'path': 'qunit/qunit.js',
    }, name='qunit_js'),
    url(r'^qunit/qunit.css', 'django.views.static.serve', {
        'document_root': media_root, 'path': 'qunit/qunit.css',
    }, name='qunit_css'),
    url('^(?P<path>.*)$', 'django_qunit.views.run_tests',
        name='qunit_test_overview'),
)



#!/usr/bin/env python
from distutils.core import setup

setup(
    name='django-qunit',
    version='0.1.1',
    description='QUnit Javascript testing integration for Django.',
    long_description=open('README.md').read(),
    author='Cody Soyland',
    author_email='codysoyland@gmail.com',
    url='http://github.com/codysoyland/django-qunit/',
    packages=[
        'django_qunit',
    ],
    package_data={
        'django_qunit': ['templates/qunit/*', 'media/qunit/*'],
    },
    classifiers=['Development Status :: 3 - Alpha',
                 'Environment :: Web Environment',
                 'Framework :: Django',
                 'Intended Audience :: Developers',
                 'License :: OSI Approved :: BSD License',
                 'Operating System :: OS Independent',
                 'Programming Language :: Python',
                 'Programming Language :: JavaScript',
                 'Topic :: Software Development :: Testing'],
)
